# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.10] - 2026-03-27

### Fixed
- Fix wildcard-imports issues (ticket-f59adb71)
- Fix wildcard-imports issues (ticket-e0342587)
- Fix wildcard-imports issues (ticket-f50ed65e)

## [0.1.10] - 2026-03-27

### Fixed
- Fix duplicate-imports issues (ticket-49d37755)

## [0.1.10] - 2026-03-27

### Fixed
- Fix smart-return-type issues (ticket-7adcbb2b)
- Fix string-concat issues (ticket-242b0517)
- Fix unused-imports issues (ticket-de239fa7)
- Fix magic-numbers issues (ticket-02dc0d73)
- Fix ai-boilerplate issues (ticket-b38b2991)
- Fix llm-generated-code issues (ticket-b3a94431)
- Fix smart-return-type issues (ticket-e338c3a9)
- Fix string-concat issues (ticket-133af5e9)
- Fix ai-boilerplate issues (ticket-054d6766)

## [0.1.22] - 2026-03-27

### Added
- Parallel processing support for faster scanning (configurable max_workers)
- Smart file filtering to skip large files (>100KB) and empty files
- Autonomous mode header with version information
- Deduplication logic for TODO.md and planfile.yaml tickets

### Changed
- Removed deprecated `print-statement` rule from pylint configuration
- Optimized exclude patterns to include test directories and examples
- Updated header display to be more compact

### Fixed
- Escape sequence issues in f-strings causing Python 3.8 compatibility errors
- Duplicate ticket creation within the same run
- Unused imports across multiple modules (cli.py, logging.py, plugins, rules)
- String concatenation issues converted to f-strings

### Code Cleanup
- Removed unused `from __future__ import annotations` from multiple files
- Cleaned up unused imports (json, shutil, os, pickle, etc.)
- Removed duplicate imports in autoflake_based.py and unimport_based.py
- Simplified type annotations by removing unused Union imports

## [0.1.10] - 2026-03-27

### Fixed
- Fix wildcard-imports issues (ticket-eddf6c3b)
- Fix magic-numbers issues (ticket-3e1f69d6)

## [0.1.10] - 2026-03-27

### Fixed
- Fix print-statements issues (ticket-6d9734af)
- Fix print-statements issues (ticket-795ea948)
- Fix print-statements issues (ticket-fece0ed9)
- Fix print-statements issues (ticket-757cb576)
- Fix print-statements issues (ticket-a9f2d25a)
- Fix print-statements issues (ticket-3200084a)
- Fix print-statements issues (ticket-f60ee670)
- Fix print-statements issues (ticket-c3f4716c)
- Fix print-statements issues (ticket-e548d604)
- Fix print-statements issues (ticket-e2222289)
- Fix print-statements issues (ticket-fc637bc5)
- Fix print-statements issues (ticket-2fa3e811)
- Fix print-statements issues (ticket-4cb672d3)
- Fix print-statements issues (ticket-a878d687)
- Fix print-statements issues (ticket-df7df4bf)
- Fix print-statements issues (ticket-9569e7a8)
- Fix print-statements issues (ticket-b05d4c89)
- Fix print-statements issues (ticket-c0f9550b)
- Fix print-statements issues (ticket-14c47fd3)
- Fix print-statements issues (ticket-acbb7841)
- Fix print-statements issues (ticket-48264d64)
- Fix print-statements issues (ticket-e7625bb7)
- Fix print-statements issues (ticket-686e96f8)
- Fix print-statements issues (ticket-c82c5990)
- Fix print-statements issues (ticket-a22fd598)
- Fix print-statements issues (ticket-7ce27c3e)
- Fix print-statements issues (ticket-7be9d520)
- Fix print-statements issues (ticket-79bcc9dd)
- Fix print-statements issues (ticket-6454bdff)
- Fix print-statements issues (ticket-768aac28)
- Fix print-statements issues (ticket-2f49542e)
- Fix print-statements issues (ticket-b2529fa3)
- Fix print-statements issues (ticket-2f1579b3)
- Fix print-statements issues (ticket-7223b67c)
- Fix print-statements issues (ticket-b80a85fb)
- Fix print-statements issues (ticket-0f492025)
- Fix print-statements issues (ticket-10492ac4)
- Fix print-statements issues (ticket-7a4239d5)
- Fix print-statements issues (ticket-a618f91f)
- Fix print-statements issues (ticket-fa9f7222)
- Fix print-statements issues (ticket-51e9c5a1)
- Fix print-statements issues (ticket-93495c2a)
- Fix print-statements issues (ticket-ec5d40e1)
- Fix print-statements issues (ticket-f9c1c389)
- Fix print-statements issues (ticket-fae31cac)
- Fix print-statements issues (ticket-e934a0e7)
- Fix print-statements issues (ticket-88915d9c)
- Fix print-statements issues (ticket-0aff9891)

## [0.1.10] - 2026-03-27

### Fixed
- Fix smart-return-type issues (ticket-474934b5)

## [0.1.10] - 2026-03-27

### Fixed
- Fix smart-return-type issues (ticket-e5c41121)
- Fix unused-imports issues (ticket-c7040878)
- Fix duplicate-imports issues (ticket-2cedfab5)
- Fix smart-return-type issues (ticket-335bf45a)
- Fix unused-imports issues (ticket-12f6d274)
- Fix smart-return-type issues (ticket-aa700792)
- Fix string-concat issues (ticket-9afae806)
- Fix smart-return-type issues (ticket-68301c01)
- Fix string-concat issues (ticket-d267051a)
- Fix smart-return-type issues (ticket-9e8194af)
- Fix string-concat issues (ticket-e2d80bc7)
- Fix smart-return-type issues (ticket-1ae4258d)
- Fix string-concat issues (ticket-bec2cb81)
- Fix wildcard-imports issues (ticket-a2e64792)
- Fix smart-return-type issues (ticket-4cef4c7a)
- Fix unused-imports issues (ticket-d2c3e43b)
- Fix relative-imports issues (ticket-c0780edb)
- Fix wildcard-imports issues (ticket-7aa3be91)
- Fix smart-return-type issues (ticket-87e8421d)
- Fix unused-imports issues (ticket-6ceca6cd)
- Fix relative-imports issues (ticket-9ee30c8e)
- Fix smart-return-type issues (ticket-7bd7e33c)
- Fix unused-imports issues (ticket-c8d2b79e)
- Fix relative-imports issues (ticket-cc0d8678)
- Fix smart-return-type issues (ticket-f45edd2b)
- Fix unused-imports issues (ticket-64105d2e)
- Fix smart-return-type issues (ticket-ae74ef07)
- Fix smart-return-type issues (ticket-91f8cb20)
- Fix string-concat issues (ticket-8f7076da)
- Fix unused-imports issues (ticket-42141651)
- Fix relative-imports issues (ticket-0f5d1f57)
- Fix duplicate-imports issues (ticket-f9a73874)
- Fix wildcard-imports issues (ticket-8fd5dae2)
- Fix smart-return-type issues (ticket-a9282a1f)
- Fix unused-imports issues (ticket-efb6b7e2)
- Fix relative-imports issues (ticket-00a3f06d)
- Fix duplicate-imports issues (ticket-55266c45)
- Fix wildcard-imports issues (ticket-dec18fad)
- Fix smart-return-type issues (ticket-436f3f9d)
- Fix unused-imports issues (ticket-a465f85b)
- Fix relative-imports issues (ticket-7b7ddd05)
- Fix smart-return-type issues (ticket-a3daf553)
- Fix string-concat issues (ticket-08d58ab6)
- Fix unused-imports issues (ticket-16e09896)
- Fix relative-imports issues (ticket-e0e2d8d3)
- Fix smart-return-type issues (ticket-7a0af27c)
- Fix string-concat issues (ticket-725a26b4)
- Fix unused-imports issues (ticket-c376c43d)
- Fix relative-imports issues (ticket-cefb0cd0)
- Fix smart-return-type issues (ticket-e54a5b66)
- Fix string-concat issues (ticket-70a06a1a)
- Fix unused-imports issues (ticket-174738fc)
- Fix llm-hallucinations issues (ticket-f3bf766d)
- Fix magic-numbers issues (ticket-ced904ab)
- Fix ai-boilerplate issues (ticket-3af627ed)
- Fix unused-imports issues (ticket-8b59d371)
- Fix smart-return-type issues (ticket-84cb419e)
- Fix unused-imports issues (ticket-278ef2b0)
- Fix ai-boilerplate issues (ticket-2dc37273)
- Fix relative-imports issues (ticket-abbade75)
- Fix smart-return-type issues (ticket-cecef1df)
- Fix string-concat issues (ticket-a7ba4dbb)
- Fix unused-imports issues (ticket-2de86a57)
- Fix ai-boilerplate issues (ticket-cbafd961)
- Fix wildcard-imports issues (ticket-e6121711)
- Fix smart-return-type issues (ticket-5a5bf7e1)
- Fix string-concat issues (ticket-15e3961b)
- Fix smart-return-type issues (ticket-697d9c38)
- Fix string-concat issues (ticket-3872e251)
- Fix smart-return-type issues (ticket-486ac306)
- Fix string-concat issues (ticket-d2629c69)
- Fix string-concat issues (ticket-8dcd309d)
- Fix unused-imports issues (ticket-d724da7f)
- Fix unused-imports issues (ticket-a7f2cee8)
- Fix duplicate-imports issues (ticket-a0b0d439)
- Fix ai-boilerplate issues (ticket-d7787f83)
- Fix unused-imports issues (ticket-c8c68ad9)
- Fix duplicate-imports issues (ticket-f1dc440b)
- Fix unused-imports issues (ticket-a125ae3a)
- Fix magic-numbers issues (ticket-743317da)
- Fix unused-imports issues (ticket-567f430c)
- Fix string-concat issues (ticket-2e3f5471)
- Fix unused-imports issues (ticket-f8c0c326)
- Fix smart-return-type issues (ticket-cb6e6df9)
- Fix unused-imports issues (ticket-cc6e4430)
- Fix ai-boilerplate issues (ticket-81d2165c)
- Fix smart-return-type issues (ticket-00517738)
- Fix unused-imports issues (ticket-6b47cff0)
- Fix unused-imports issues (ticket-7bd1f986)
- Fix smart-return-type issues (ticket-e6cf1eb3)
- Fix string-concat issues (ticket-38c5eb42)
- Fix unused-imports issues (ticket-12e03e69)
- Fix magic-numbers issues (ticket-53162289)
- Fix smart-return-type issues (ticket-9aa919bc)
- Fix string-concat issues (ticket-8142b3c5)
- Fix unused-imports issues (ticket-606216db)
- Fix duplicate-imports issues (ticket-7ee8f0ef)
- Fix smart-return-type issues (ticket-b2fb9f0b)
- Fix unused-imports issues (ticket-32e41cd5)
- Fix unused-imports issues (ticket-36c4092a)
- Fix string-concat issues (ticket-5bc52af6)
- Fix unused-imports issues (ticket-eb8d091c)
- Fix unused-imports issues (ticket-48240d17)
- Fix unused-imports issues (ticket-60197482)
- Fix ai-boilerplate issues (ticket-7a5bf382)
- Fix unused-imports issues (ticket-e6c1f103)
- Fix duplicate-imports issues (ticket-1f499a4a)
- Fix smart-return-type issues (ticket-a3166b4a)
- Fix string-concat issues (ticket-4f278902)
- Fix unused-imports issues (ticket-68ac49fc)
- Fix ai-boilerplate issues (ticket-05c02e79)
- Fix unused-imports issues (ticket-facaf445)
- Fix unused-imports issues (ticket-0a68ccfd)
- Fix unused-imports issues (ticket-13ac6579)
- Fix unused-imports issues (ticket-7734659e)
- Fix duplicate-imports issues (ticket-3d5a1915)
- Fix string-concat issues (ticket-2f2a9221)
- Fix unused-imports issues (ticket-7d58a4b6)
- Fix string-concat issues (ticket-131fbc36)
- Fix unused-imports issues (ticket-458db142)
- Fix magic-numbers issues (ticket-2f8b17e3)
- Fix unused-imports issues (ticket-dad85add)
- Fix unused-imports issues (ticket-8aa902e0)
- Fix llm-hallucinations issues (ticket-f64489cc)
- Fix unused-imports issues (ticket-277e8b8f)
- Fix smart-return-type issues (ticket-9f7d86b9)
- Fix unused-imports issues (ticket-8f1b147c)
- Fix unused-imports issues (ticket-257a5ae7)
- Fix duplicate-imports issues (ticket-e03eed7f)
- Fix unused-imports issues (ticket-56ef4f69)
- Fix smart-return-type issues (ticket-12ffcc71)
- Fix unused-imports issues (ticket-ee28bc63)
- Fix unused-imports issues (ticket-89cf2ac3)
- Fix string-concat issues (ticket-349127ce)
- Fix unused-imports issues (ticket-cde03f37)
- Fix llm-hallucinations issues (ticket-ba72d983)
- Fix unused-imports issues (ticket-34a2bf6e)
- Fix unused-imports issues (ticket-0fbf05e2)
- Fix magic-numbers issues (ticket-238dae90)
- Fix unused-imports issues (ticket-570b6e00)
- Fix string-concat issues (ticket-aa92c01c)
- Fix unused-imports issues (ticket-99263596)
- Fix smart-return-type issues (ticket-22e7fcbf)
- Fix unused-imports issues (ticket-7c04a88f)
- Fix magic-numbers issues (ticket-83c9d2ab)
- Fix unused-imports issues (ticket-ac97ab7a)
- Fix string-concat issues (ticket-9508f720)
- Fix unused-imports issues (ticket-76cb20e3)
- Fix duplicate-imports issues (ticket-0c3365f2)
- Fix string-concat issues (ticket-fa84f94a)
- Fix unused-imports issues (ticket-7a513113)
- Fix unused-imports issues (ticket-9300959f)
- Fix string-concat issues (ticket-ace03dcb)
- Fix unused-imports issues (ticket-d5b7fa6d)
- Fix unused-imports issues (ticket-c1ba2cf8)

## [Unreleased]

## [0.1.25] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update TODO.md
- Update docs/RAM_OPTIMIZATION.md
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Test
- Update test_large_files.py
- Update test_ram_implementation.py

### Other
- Update benchmark_ram_optimization.py
- Update planfile.yaml
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- ... and 5 more files

## [0.1.24] - 2026-03-27

## [0.1.23] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update README.md
- Update TODO.md
- Update docs/README.md
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- Update project/prompt.txt

## [0.1.22] - 2026-03-27

### Docs
- Update TODO.md
- Update docs/README.md
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml

## [0.1.21] - 2026-03-27

### Docs
- Update TODO.md
- Update docs/README.md

### Other
- Update project/duplication.toon.yaml

## [0.1.20] - 2026-03-27

### Docs
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml

## [0.1.19] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update TODO.md
- Update docs/README.md
- Update project/context.md

### Other
- Update planfile.yaml
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- ... and 3 more files

## [0.1.18] - 2026-03-27

### Other
- Update prefact.yaml

## [0.1.17] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update TODO.md

### Other
- Update planfile.yaml

## [0.1.16] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update TODO.md
- Update docs/README.md
- Update project/context.md

### Other
- Update planfile.yaml
- Update prefact.yaml
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- ... and 4 more files

## [0.1.15] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Other
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- ... and 3 more files

## [0.1.14] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml

## [0.1.13] - 2026-03-27

### Docs
- Update README.md
- Update docs/README.md
- Update project/context.md

### Other
- Update img.png
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- ... and 1 more files

## [0.1.12] - 2026-03-27

## [0.1.11] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/context.md

### Other
- Update PKG-INFO
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- ... and 2 more files

## [0.1.10] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- ... and 1 more files

## [0.1.9] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update README.md
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Other
- Update prefact.yaml
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- ... and 7 more files

## [0.1.8] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Other
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- ... and 4 more files

## [0.1.7] - 2026-03-27

### Docs
- Update project/context.md

### Other
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/flow.mmd
- Update project/map.toon.yaml

## [0.1.6] - 2026-03-27

### Other
- Update examples/run_examples.py
- Update planfile.yaml
- Update prefact.yaml

## [0.1.5] - 2026-03-27

### Docs
- Update examples/README.md
- Update vscode-extension/node_modules/@eslint-community/eslint-utils/README.md
- Update vscode-extension/node_modules/@eslint-community/regexpp/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/node_modules/brace-expansion/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/node_modules/minimatch/README.md
- Update vscode-extension/node_modules/@eslint/js/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/node_modules/brace-expansion/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/node_modules/minimatch/README.md
- ... and 297 more files

### Other
- Update examples/07-enterprise/prefact.yaml
- Update examples/08-llm-focused/prefact.yaml
- Update examples/09-high-performance/prefact.yaml
- Update examples/10-plugin-development/prefact.yaml
- Update examples/11-ci-cd/prefact.yaml
- Update examples/12-complete-example/prefact.yaml
- Update examples/requirements.txt
- Update src/prefact/VERSION
- Update vscode-extension/node_modules/.bin/acorn
- Update vscode-extension/node_modules/.bin/eslint
- ... and 965 more files

## [0.1.4] - 2026-03-27

### Docs
- Update README.md
- Update docs/MIGRATION_GUIDE.md
- Update examples/01-individual-rules/README.md
- Update examples/06-api-usage/README.md
- Update examples/README.md
- Update examples/sample-project/README.md

### Test
- Update tests/test_integrations.py

### Other
- Update examples/requirements.txt

## [0.1.3] - 2026-03-27

### Docs
- Update examples/01-individual-rules/duplicate-imports/README.md
- Update examples/01-individual-rules/missing-return-type/README.md
- Update examples/01-individual-rules/print-statements/README.md
- Update examples/01-individual-rules/relative-imports/README.md
- Update examples/01-individual-rules/sorted-imports/README.md
- Update examples/01-individual-rules/string-concat/README.md
- Update examples/01-individual-rules/wildcard-imports/README.md

### Other
- Update examples/03-output-formats/test-report.json
- Update examples/run_all.sh

## [0.1.2] - 2026-03-27

### Docs
- Update README.md
- Update examples/01-individual-rules/README.md
- Update examples/02-multiple-rules/README.md
- Update examples/03-output-formats/README.md
- Update examples/04-custom-rules/README.md
- Update examples/05-ci-cd/README.md
- Update examples/06-api-usage/README.md
- Update examples/README.md
- Update examples/sample-project/README.md

### Other
- Update examples/01-individual-rules/duplicate-imports/after.py
- Update examples/01-individual-rules/duplicate-imports/before.py
- Update examples/01-individual-rules/duplicate-imports/prefact.yaml
- Update examples/01-individual-rules/missing-return-type/after.py
- Update examples/01-individual-rules/missing-return-type/before.py
- Update examples/01-individual-rules/missing-return-type/prefact.yaml
- Update examples/01-individual-rules/print-statements/after.py
- Update examples/01-individual-rules/print-statements/before.py
- Update examples/01-individual-rules/print-statements/prefact.yaml
- Update examples/01-individual-rules/relative-imports/after.py
- ... and 39 more files

## [0.1.1] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_config.py
- Update tests/test_engine.py
- Update tests/test_relative_imports.py
- Update tests/test_rules.py
- Update tests/test_unused_imports.py

### Other
- Update PKG-INFO
- Update VERSION
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.6] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_prefactoring.py

### Other
- Update MANIFEST.in
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.5] - 2026-03-27

### Other
- Update .idea/inspectionProfiles/Project_Default.xml
- Update .idea/inspectionProfiles/profiles_settings.xml
- Update .idea/misc.xml
- Update .idea/modules.xml
- Update .idea/prefactoring.iml
- Update .idea/vcs.xml

## [0.0.4] - 2026-03-27

## [0.0.3] - 2026-03-27

### Other
- Update MANIFEST.in

## [0.0.2] - 2026-03-27

### Test
- Update tests/test_prefactoring.py

### Other
- Update prefactoring/__init__.py
- Update prefactoring/cli.py
- Update prefactoring/core.py
- Update prefactoring/utils.py

## [0.0.1] - 2026-03-27

### Other
- Update .idea/.gitignore

